@@ -28,5 +28,13 @@ Full documentation @ <https://akamhy.github.io/waybackpy/>.
 """
 
 from .wrapper import Url
-from .__version__ import __title__, __description__, __url__, __version__
-from .__version__ import __author__, __author_email__, __license__, __copyright__
+from .__version__ import (
+    __title__,
+    __description__,
+    __url__,
+    __version__,
+    __author__,
+    __author_email__,
+    __license__,
+    __copyright__,
+)
